
Include "data_Rsole.geo";


Group{
  Domaine = Region[{CONDUCTEUR}];
  
  Sentree = Region[{SENTREE}];
  Ssortie = Region[{SSORTIE}];
}

Function{
  Sigma[] = sigma;
}

Jacobian{
  { Name Jvol;
    Case {
      { Region All ; Jacobian Vol; }
    }
  }
}

Integration {
  { Name Integ;
    Case { 
      {Type Gauss;
	Case { 
	  { GeoElement Quadrangle ; NumberOfPoints 4; }
	  { GeoElement Hexahedron ; NumberOfPoints 6; }
	}
      }
    }
  }
}

Constraint {	
  {Name Dirichlet ;
    Case {      
      {Region Sentree ; Type Assign ; Value Veff ;}
      {Region Ssortie ; Type Assign ; Value 0. ;}
    }
  }
}

FunctionSpace {
  { Name Hgrad_v ; Type Form0 ; 
    BasisFunction { 
      { Name sn ; NameOfCoef vn ; Function BF_Node ; 
	Support Region[{Domaine}]  ; Entity NodesOf[All] ; }
    } 
    Constraint {
      { NameOfCoef vn  ; EntityType NodesOf ; NameOfConstraint Dirichlet ; }
    }
  }
}


Formulation {
  { Name Electrocinetique ; Type FemEquation ;
    Quantity {
      { Name v  ; Type Local  ; NameOfSpace Hgrad_v ; }
    } 
    Equation {
      Galerkin { [ Sigma[]*Dof{Grad v}  , {Grad v} ] ;
	In Domaine ; Jacobian Jvol ; Integration Integ ; }
     }
  }
}


Resolution {
  { Name analyse ;
    System {
      { Name Sys ; NameOfFormulation Electrocinetique ; }
    }
    Operation {
      Generate[Sys] ; 
      Solve[Sys] ;
      SaveSolution[Sys] ;
    }
  }
}


PostProcessing {
  { Name PostProc ; NameOfFormulation Electrocinetique ;
    Quantity {	
      { Name v  ; Value { Term { [ {v} ] ; 
	    In Domaine ; Jacobian Jvol ; } } }
      { Name j  ; Value { Term { [ -Sigma[]*{Grad v} ] ; 
	    In Domaine ; Jacobian Jvol ; } } }
      { Name pv  ; Value { Term { [ Sigma[]*SquNorm[{Grad v}] ] ; 
	    In Domaine ; Jacobian Jvol ; } } } 
      { Name Pj  ; Value { Integral { [ Sigma[]*SquNorm[{Grad v}] ] ; 
	    In Domaine ; Jacobian Jvol ; Integration Integ ;} } } 
    }
  }
}

PostOperation PostOp UsingPost PostProc {
  Print[ v, OnElementsOf Domaine, File "v.pos"] ;
  Print[ j, OnElementsOf Domaine, File "j.pos"] ;
  Print[ pv, OnElementsOf Domaine, File "pv.pos"] ;
  Print[ Pj[Domaine], OnGlobal, File "Puissance.dat", 
    SendToServer "Resultats/Pertes Joule [W]", Color "AliceBlue" ];
}
